import os

import PythonFaceSDK as sdk

IDLIVEFACE_HOME = r"/opt/idliveface"


def process_liveness_result(result):
    print(f"Result: {result}")

    if result.quality_result.score < 0.5:
        print("Image has a bad quality")
    elif result.liveness_result.probability >= 0.5:
        print("Image is genuine")
    else:
        print("Image is spoofed")


def main():
    try:
        print("Initializing...")
        config = sdk.InitConfig.createConfig(os.path.join(IDLIVEFACE_HOME, "data/pipelines/astraea.json"))
        pipeline = sdk.FaceSDK.getPipeline("ConfigurablePipeline", config)

        print("\nChecking liveness for real_face.jpg")
        image = sdk.Image.createImage(os.path.join(IDLIVEFACE_HOME, "examples/images/real_face.jpg"))
        liveness_result = pipeline.checkLiveness(image)
        process_liveness_result(liveness_result)

        print("\nChecking liveness for spoof_face.jpg")
        image = sdk.Image.createImage(os.path.join(IDLIVEFACE_HOME, "examples/images/spoof_face.jpg"))
        liveness_result = pipeline.checkLiveness(image)
        process_liveness_result(liveness_result)

        print("\nChecking liveness for face_not_found.jpg")
        image = sdk.Image.createImage(os.path.join(IDLIVEFACE_HOME, "examples/images/face_not_found.jpg"))
        pipeline.checkLiveness(image)

    except RuntimeError as e:
        face_exception = e.args[0]
        print(f"Error: {face_exception.status()}, message: {face_exception.what()}")


if __name__ == "__main__":
    main()
